hello.fiftyone.evaluate\_segmentations module
=============================================

.. automodule:: hello.fiftyone.evaluate_segmentations
   :members:
   :undoc-members:
   :show-inheritance:
